@@ -1,14 +1,16 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+from . import rowingdata
 from sys import argv
 
 def main():
     readFile=argv[1]
 
     try:
-	rowerFile=argv[2]
+        rowerFile=argv[2]
     except IndexError:
-	rowerFile="defaultrower.txt"
+        rowerFile="defaultrower.txt"
 
     rower=rowingdata.getrower(rowerFile)
 
@@ -19,9 +21,9 @@ def main():
     tcx.write_nogeo_csv(csvoutput,window_size=20)
 
     res=rowingdata.rowingdata(csvoutput,rowtype="On-water",
-				rower=rower)
+                                rower=rower)
 
-    print(res.allstats())
+    print((res.allstats()))
     rowingdata.copytocb(res.allstats())
 
 
@@ -33,4 +35,4 @@ def main():
 
 
 
-    print("done "+readFile)
+    print(("done "+readFile))
