@@ -1,21 +1,24 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+from . import rowingdata
 from sys import argv
+from six.moves import input
 
 def main():
     readFile=argv[1]
 
     try:
-	rowerFile=argv[2]
+        rowerFile=argv[2]
     except IndexError:
-	rowerFile="defaultrower.txt"
+        rowerFile="defaultrower.txt"
 
     rower=rowingdata.getrower(rowerFile)
 
     try:
-	boatFile=argv[3]
+        boatFile=argv[3]
     except IndexError:
-	boatFile="my1x.txt"
+        boatFile="my1x.txt"
 
 
     csvoutput=readFile+'_p.csv'
@@ -24,12 +27,12 @@ def main():
     tcx.write_csv(csvoutput,window_size=20)
 
     res=rowingdata.rowingdata(csvoutput,rowtype="On-water",
-				rower=rower)
+                                rower=rower)
 
-    s=raw_input('Enter wind speed: ')
+    s=input('Enter wind speed: ')
     windv=float(s)
-    u=raw_input('Enter wind speed units m=m/s, b=beaufort, k=knots: ')
-    s=raw_input('Enter wind bearing (N=0, E=90, S=180, W=270): ')
+    u=input('Enter wind speed units m=m/s, b=beaufort, k=knots: ')
+    s=input('Enter wind bearing (N=0, E=90, S=180, W=270): ')
     winddirection=float(s)
 
     res.add_wind(windv,winddirection,units=u)
@@ -42,4 +45,4 @@ def main():
     res.plottime_otwpower()
 
 
-    print("done "+readFile)
+    print(("done "+readFile))
